%% CODE TO RUN PEB MODEL AND TEST MRS-GABA EFFECTS

% This code needs the usual your_paths.txt file with all the info on your paths. 
% An example is provided on GIT.

% This code is an authomatized script to run PEB analysis with a regressor.
% In this case we regress the MRS-derived metrics to the NMM output. We
% will just focus on the T and H output of the NMM because they store
% receptors and connections info respectively. 

%-----------------------------------------------------------------------
% Written by I. Paparella
% Cyclotron Research Centre, University of Liege, Belgium
% 26th February 2025


function PEB_analysis_withCycle


%% Path info
paths_txt = fileread('your_paths.txt') ;
paths_txt = char(strsplit(paths_txt, '\n')) ;

paths = [];
paths.data = (strtrim(paths_txt(2,:)));
paths.spm = (strtrim(paths_txt(4,:)));
paths.codes = (strtrim(paths_txt(8,:)));

addpath(paths.spm)
%% Define folder to store analysis into
PEB_path= strcat(paths.data, '/PEB');

%% Start the PEB analysis
% To test whether TMS-EEG and MRS GABA metrics are related we will
% conduct a PEB analysis putting the MRS derived GABA metric as regressor
% as described here: (https://en.wikibooks.org/wiki/SPM/Parametric_Empirical_Bayes_(PEB))


% First let's create a folder to store the output of this PEB analysis
PEB_MRS_NMM = strcat(PEB_path, '/PEB_MRS_NMM_FHK_AllFemale_GABA_withCycle');
mkdir(PEB_MRS_NMM);

% We load the GCMs 
GCM_all = load(strcat(PEB_path, '/GCM_FHK_allFemale.mat'));
GCM_all.GCM{11,1}= []; % remove STR7T_HS_015 -> no menstrual cycle due to contracceptive pill

% Load the MRS info
subjToExclude = 15; %015 who has no cycle due to contracceptive pill
MRS = load(strcat(paths.data, '/MRS_GABA_FHK_AllSubjects.txt'));
MRS(ismember(MRS(:,1), subjToExclude),:) = [];

% Load table with cycle info
MensCycle = load(strcat(paths.data, '/MensCycle.txt'));

% We define a design matrix X1 with regressors:
% Mean
% MRS-derived GABA
% Interpret: as correlation (if positive = higher MRS, higher NMM; if
% negative the other way around)
    
% Then we create the design matrix
X1= [ones(size(GCM_all.GCM,1),1) MRS(:,2) MensCycle];
X1(:,2) = X1(:,2) - mean(X1(:,2)); % mean center the 2nd column so that the
%first column can be taken as mean connectivity across subjects. If we
%don't mean center the first column will be taken as baseline
X1(:,3) = X1(:,3) - mean(X1(:,3));

X1_labels = {'Mean_connectivity', 'MRS', 'Cycle'};

% Fit to all DCMs from old in a single column vector:
GCM = GCM_all.GCM;

% PEB setting and Run PEB
M = struct();
M.Q = 'all';
M.X= X1;
M.Xnames = X1_labels;

[PEB ,RCM] = spm_dcm_peb(GCM, M, {'T', 'H'}); % need to set the field otherwise the
% default will be matrix A and B (set on the MRI) which we don't have in
% NMM

% Save the output in the respective folder & run BMA
save(strcat(PEB_MRS_NMM, '/PEB_MRS_NMM_FHK_allFemale_GABA.mat'),'PEB','RCM');

BMA = spm_dcm_peb_bmc(PEB);
save(strcat(PEB_MRS_NMM,'/BMA_PEB_MRS_NMM_FHK_allFemale_GABA.mat'),'BMA');

% LOO cross-validation
spm_dcm_loo(GCM,M,{'H(3,3)'}); % on IIfeedbackLoop
spm_dcm_loo(GCM,M,{'H(3,4)'}); % on II-DP connection
    
end

% spm_dcm_peb_review(BMA); to review results